@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-02-22'; # DATE
-our $VERSION = '0.55'; # VERSION
+our $DATE = '2016-02-26'; # DATE
+our $VERSION = '0.56'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -18,11 +18,7 @@ use Perinci::Sub::To::CLIDocData qw(gen_cli_doc_data_from_meta);
 use Perinci::To::POD;
 use Scalar::Util qw(blessed);
 
-our $pa = Perinci::Access::Perl->new(
-    # we want to document the function's original properties (i.e. result_naked
-    # and args_as)
-    normalize_metadata => 0,
-);
+our $pa = Perinci::Access::Perl->new;
 
 # regex
 has exclude_modules => (
@@ -795,7 +791,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.55 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-02-22.
+This document describes version 0.56 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-02-26.
 
 =head1 SYNOPSIS
 
